<?php

/*
 * This file is part of the Sylius package.
 *
 * (c) Paweł Jędrzejewski
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Sylius\Bundle\GridBundle\Form\Type\Filter;

use Sylius\Component\Grid\Filter\StringFilter;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;

/**
 * Sylius choice filter type.
 *
 * @author Paweł Jędrzejewski <pawel@sylius.org>
 */
class ChoiceFilterType extends AbstractType
{
    /**
     * {@inheritdoc}
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('value', 'choice', array(
                'required' => false,
                'choices'  => $options['choices'],
                'multiple' => $options['multiple'],
                'expanded' => $options['expanded'],
            ))
        ;
    }

    /**
     * {@inheritdoc}
     */
    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        $resolver
            ->setDefaults(array(
                'data_class' => null,
                'multiple'   => false,
                'expanded'   => false,
            ))
            ->setRequired(array(
                'choices'
            ))
            ->setAllowedTypes(array(
                'choices'  => array('array'),
                'multiple' => array('bool'),
                'expanded' => array('bool'),
            ))
        ;
    }

    /**
     * {@inheritdoc}
     */
    public function getName()
    {
        return 'sylius_filter_choice';
    }
}
