<?php

/*
 * This file is part of the Sylius package.
 *
 * (c) Paweł Jędrzejewski
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Sylius\Bundle\PaymentBundle\Form\Type;

use Doctrine\ORM\EntityRepository;
use Symfony\Component\OptionsResolver\Options;
use Symfony\Component\OptionsResolver\OptionsResolverInterface;

/**
 * Payment method choice type for "doctrine/orm" driver.
 *
 * @author Paweł Jędrzejewski <pawel@sylius.org>
 */
class PaymentMethodEntityType extends PaymentMethodChoiceType
{
    /**
     * {@inheritdoc}
     */
    public function setDefaultOptions(OptionsResolverInterface $resolver)
    {
        parent::setDefaultOptions($resolver);

        $queryBuilder = function (Options $options) {
            if (!$options['disabled']) {
                return function (EntityRepository $repository) {
                    return $repository->createQueryBuilder('method')->where('method.enabled = true');
                };
            } else {
                return function (EntityRepository $repository) {
                    return $repository->createQueryBuilder('method');
                };
            }
        };

        $resolver
            ->setDefaults(array(
                'query_builder' => $queryBuilder
            ))
        ;
    }

    /**
     * {@inheritdoc}
     */
    public function getParent()
    {
        return 'entity';
    }
}
